@@ -1,7 +1,6 @@
 package command
 
 import (
-	"bytes"
 	"fmt"
 	"io/ioutil"
 	"math"
@@ -13,15 +12,6 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/hashicorp/go-uuid"
-	packersdk "github.com/hashicorp/packer-plugin-sdk/packer"
-	"github.com/hashicorp/packer/builder/file"
-	"github.com/hashicorp/packer/builder/null"
-	"github.com/hashicorp/packer/packer"
-	"github.com/hashicorp/packer/post-processor/manifest"
-	shell_local_pp "github.com/hashicorp/packer/post-processor/shell-local"
-	filep "github.com/hashicorp/packer/provisioner/file"
-	"github.com/hashicorp/packer/provisioner/shell"
-	shell_local "github.com/hashicorp/packer/provisioner/shell-local"
 )
 
 var (
@@ -426,6 +416,25 @@ func TestBuild(t *testing.T) {
 				},
 			},
 		},
+
+		{
+			name: "hcl - test crash #11381",
+			args: []string{
+				testFixture("hcl", "nil-component-crash.pkr.hcl"),
+			},
+			expectedCode: 1,
+		},
+		{
+			name: "hcl - using variables in build block",
+			args: []string{
+				testFixture("hcl", "vars-in-build-block.pkr.hcl"),
+			},
+			fileCheck: fileCheck{
+				expectedContent: map[string]string{
+					"example.2.txt": two,
+				},
+			},
+		},
 	}
 
 	for _, tt := range tc {
@@ -495,7 +504,7 @@ func Test_build_output(t *testing.T) {
 
 func TestBuildOnlyFileCommaFlags(t *testing.T) {
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 
 	args := []string{
@@ -528,7 +537,7 @@ func TestBuildOnlyFileCommaFlags(t *testing.T) {
 
 func TestBuildStdin(t *testing.T) {
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 	f, err := os.Open(filepath.Join(testFixture("build-only"), "template.json"))
 	if err != nil {
@@ -555,7 +564,7 @@ func TestBuildStdin(t *testing.T) {
 
 func TestBuildOnlyFileMultipleFlags(t *testing.T) {
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 
 	args := []string{
@@ -589,7 +598,7 @@ func TestBuildOnlyFileMultipleFlags(t *testing.T) {
 
 func TestBuildProvisionAndPosProcessWithBuildVariablesSharing(t *testing.T) {
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 
 	args := []string{
@@ -616,7 +625,7 @@ func TestBuildProvisionAndPosProcessWithBuildVariablesSharing(t *testing.T) {
 
 func TestBuildEverything(t *testing.T) {
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 
 	args := []string{
@@ -641,7 +650,7 @@ func TestBuildEverything(t *testing.T) {
 
 func TestBuildExceptFileCommaFlags(t *testing.T) {
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 	tc := []struct {
 		name                     string
@@ -714,7 +723,7 @@ func TestBuildExceptFileCommaFlags(t *testing.T) {
 
 func testHCLOnlyExceptFlags(t *testing.T, args, present, notPresent []string) {
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 
 	defer cleanup()
@@ -770,7 +779,7 @@ func TestHCL2PostProcessorForceFlag(t *testing.T) {
 	defer fCheck.cleanup(t)
 
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 	if code := c.Run(args); code != 0 {
 		fatalCommand(t, c.Meta)
@@ -804,7 +813,7 @@ func TestHCL2PostProcessorForceFlag(t *testing.T) {
 	}
 
 	c = &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 	if code := c.Run(args); code != 0 {
 		fatalCommand(t, c.Meta)
@@ -874,7 +883,7 @@ func TestBuildCommand_HCLOnlyExceptOptions(t *testing.T) {
 
 func TestBuildWithNonExistingBuilder(t *testing.T) {
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 
 	args := []string{
@@ -900,7 +909,7 @@ func run(t *testing.T, args []string, expectedCode int) {
 	t.Helper()
 
 	c := &BuildCommand{
-		Meta: testMetaFile(t),
+		Meta: TestMetaFile(t),
 	}
 
 	if code := c.Run(args); code != expectedCode {
@@ -952,46 +961,6 @@ func (fc fileCheck) verify(t *testing.T, dir string) {
 	}
 }
 
-// testCoreConfigBuilder creates a packer CoreConfig that has a file builder
-// available. This allows us to test a builder that writes files to disk.
-func testCoreConfigBuilder(t *testing.T) *packer.CoreConfig {
-	components := packer.ComponentFinder{
-		PluginConfig: &packer.PluginConfig{
-			Builders: packer.MapOfBuilder{
-				"file": func() (packersdk.Builder, error) { return &file.Builder{}, nil },
-				"null": func() (packersdk.Builder, error) { return &null.Builder{}, nil },
-			},
-			Provisioners: packer.MapOfProvisioner{
-				"shell-local": func() (packersdk.Provisioner, error) { return &shell_local.Provisioner{}, nil },
-				"shell":       func() (packersdk.Provisioner, error) { return &shell.Provisioner{}, nil },
-				"file":        func() (packersdk.Provisioner, error) { return &filep.Provisioner{}, nil },
-			},
-			PostProcessors: packer.MapOfPostProcessor{
-				"shell-local": func() (packersdk.PostProcessor, error) { return &shell_local_pp.PostProcessor{}, nil },
-				"manifest":    func() (packersdk.PostProcessor, error) { return &manifest.PostProcessor{}, nil },
-			},
-			DataSources: packer.MapOfDatasource{
-				"mock": func() (packersdk.Datasource, error) { return &packersdk.MockDatasource{}, nil },
-			},
-		},
-	}
-	return &packer.CoreConfig{
-		Components: components,
-	}
-}
-
-// testMetaFile creates a Meta object that includes a file builder
-func testMetaFile(t *testing.T) Meta {
-	var out, err bytes.Buffer
-	return Meta{
-		CoreConfig: testCoreConfigBuilder(t),
-		Ui: &packersdk.BasicUi{
-			Writer:      &out,
-			ErrorWriter: &err,
-		},
-	}
-}
-
 func cleanup(moreFiles ...string) {
 	os.RemoveAll("chocolate.txt")
 	os.RemoveAll("vanilla.txt")
@@ -1014,7 +983,7 @@ func cleanup(moreFiles ...string) {
 }
 
 func TestBuildCommand_ParseArgs(t *testing.T) {
-	defaultMeta := testMetaFile(t)
+	defaultMeta := TestMetaFile(t)
 	type fields struct {
 		Meta Meta
 	}
